/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#ifndef __IP_RANGE_H_
#define __IP_RANGE_H_

#include "config.h"

#define PATTERN_SUBNET	1
#define PATTERN_RANGE	2
#define PATTERN_IP		3

#ifndef HAVE_UINT32_T
typedef unsigned int uint32_t;
#endif
typedef uint32_t ipv4addr_t;

struct Pattern_Subnet {
	ipv4addr_t IP;
	ipv4addr_t Last;
	int Valid;
};

struct Pattern_Range {
	ipv4addr_t IP;
	ipv4addr_t Start_IP;
	ipv4addr_t End_IP;
	int Valid;
};

struct Pattern_Address {
	ipv4addr_t IP;
	int Valid;
};

struct Pattern {
	int Type;
	struct Pattern_Subnet *Pattern_Subnet;
	struct Pattern_Range *Pattern_Range;
	struct Pattern_Address *Pattern_Address;
	int Valid;
};

struct IP_Address {
	ipv4addr_t IP;
	int Done;
};


int Have_Patterns();
void IP_To_String(ipv4addr_t IP, char *Buffer, int Size);
int Get_Next_IP(ipv4addr_t *IP_Address);
struct Pattern *Parse_Pattern(const char *Pattern, int Type);
int IP_Pattern_Valid(const char *Pattern);
struct Pattern* CopyPattern(struct Pattern *Old);
void Free_All_Patterns();
const char* Pattern_Type_To_String(int Type);
int New_IP_Pattern(const char *Pattern);

#endif

