/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#ifndef __PROCESSTABLE_H__
#define __PROCESSTABLE_H__

#define PROCESSTABLE_END	(-1)

typedef int ProcessTableID;

struct Process {
	pid_t PID;
	pthread_t ThreadID;		/* Thread ID of associated Redirect_Thread */
	char Running;			/* Is the process currently running? */
	int Status;				/* Return status of process (waitpid) */
	int Forwarding;			/* Is the Redirect_Thread still active? */
	int Signalling_State;	/* Was a SIGTERM/SIGKILL already issued? */
	double TermTime;
	double KillTime;
	struct Process *Prev;	/* Prev pointer for double linked list */
	struct Process *Next;	/* Next pointer for double linked list */
};

void ProcessTable_Rewind();
struct Process* ProcessTable_Next();
struct Process* ProcessTable_CreatePreliminary(double TermTime, double KillTime);
void ProcessTable_UpdateEntry_ThreadID(pthread_t ThreadID);
void ProcessTable_FinishEntry(pid_t PID);
void ProcessTable_UpdateEntry_Times(struct Process *Proc, double TermTime, double KillTime);
pid_t ProcessTable_GetCurrent_PID();
char ProcessTable_GetCurrent_Running();
double ProcessTable_GetCurrent_TermTime();
double ProcessTable_GetCurrent_KillTime();
int ProcessTable_GetCurrent_SignallingState();
char ProcessTable_Get_Running(struct Process *Proc);
pid_t ProcessTable_Get_PID(struct Process *Proc);
pthread_t ProcessTable_Get_TID(struct Process *Proc);
int ProcessTable_Get_Status(struct Process *Proc);
int ProcessTable_Get_Forwarding(struct Process *Proc);
void ProcessTable_SetCurrent_NotRunning();
void ProcessTable_SetCurrent_Status(int Status);
void ProcessTable_SetCurrent_SignallingState(int State);
void ProcessTable_Set_Forwarding_Closed(struct Process *Proc);
void ProcessTable_RemoveEntry(struct Process *ToRemove);
void ProcessTable_Free();

#endif
