/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#include <stdio.h>
#include <stdlib.h>

#include "String.h"
#include "IP_Range.h"
#include "PThreads.h"
#include "IP_Hostname_Pairings.h"
#include "Hostlist.h"

void Init_HostList(HostList *List) {
	Init_StringList(&(List->Hostnames));
	List->IP_Entries = 0;
	List->IP_Entry = NULL;
	Safe_pthread_mutex_init(&(List->Mutex), "Hostlist Mutex");
}

void Destroy_HostList(HostList *List) {
	Safe_pthread_mutex_destroy(&(List->Mutex), "Hostlist Mutex");
	free(List->IP_Entry);
	List->IP_Entry = NULL;
	List->IP_Entries = 0;
	Destroy_StringList(&(List->Hostnames));
}

void Add_Hostname(HostList *List, const char *Hostname) {
	Add_String_Unique_Atomic(&(List->Hostnames), Hostname);
}

void Add_IP_Address(HostList *List, ipv4addr_t IP_Address) {
	pthread_mutex_lock(&(List->Mutex));
	List->IP_Entries++;
	List->IP_Entry = (ipv4addr_t*)realloc(List->IP_Entry, sizeof(ipv4addr_t) * List->IP_Entries);
	if (List->IP_Entry == NULL) {
		perror("realloc");
		exit(EXIT_FAILURE);
	}
	List->IP_Entry[List->IP_Entries - 1] = IP_Address;
	pthread_mutex_unlock(&(List->Mutex));
}

/* When there is a hostname and an IP-Adress entry, prefer the IP-Address */
/* Functions is not reentrant! No locking whatsoever (Stringlist/IP-List) is performed. */
void Filter_Double_Entries(HostList *List) {
	int i;
	for (i = 0; i < List->Hostnames.Entries; i++) {
		ipv4addr_t IP;
		if (Get_IP_From_Hostname(&IP, List->Hostnames.Entry[i])) {
			Remove_String(&(List->Hostnames), i);
			i--;
		}
	}
}

