/*
	SambaScanner - A tool to scan Samba networks for files.
	Copyright (C) 2005-2007 Johannes Bauer
	
	This file is part of SambaScanner.

    SambaScanner is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; this program is ONLY licensed under
	version 2 of the License, later versions are explicitly excluded.

    SambaScanner is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SambaScanner; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

	Johannes Bauer
	Mussinanstr. 140
	92318 Neumarkt/Opf.
	JohannesBauer@gmx.de
*/

#include "config.h"

#include <stdio.h>
#include <pthread.h>
#include <unistd.h>
#include <stdlib.h>
#include <signal.h>
#include <string.h>
#include <errno.h>
#include <libintl.h>

#include "PThreads.h"
#include "sambascanner.h"

int pthread_create_detached(pthread_t *thread, void *(*start_routine)(void*), void *arg) {
	pthread_attr_t Attrs;
	pthread_attr_init(&Attrs);
	pthread_attr_setdetachstate(&Attrs, PTHREAD_CREATE_DETACHED);
	return pthread_create(thread, &Attrs, start_routine, arg);
}

void Safe_pthread_mutex_init(pthread_mutex_t *Mutex, const char *Name) {
	int Result;
	Result = pthread_mutex_init(Mutex, NULL);
	if (Result) {
		fprintf(stderr, _("pthread_mutex_init (%s): %s\n"), Name, strerror(Result));
		exit(EXIT_FAILURE);
	}
}

void Safe_pthread_cond_init(pthread_cond_t *Cond, const char *Name) {
	int Result;
	Result = pthread_cond_init(Cond, NULL);
	if (Result) {
		fprintf(stderr, _("pthread_cond_init (%s): %s\n"), Name, strerror(Result));
		exit(EXIT_FAILURE);
	}
}

void Safe_pthread_mutex_destroy(pthread_mutex_t *Mutex, const char *Name) {
	int Result;
	Result = pthread_mutex_destroy(Mutex);
	if (Result) {
		fprintf(stderr, _("pthread_mutex_destroy (%s): %s\n"), Name, strerror(Result));
	}
}

void Safe_pthread_cond_destroy(pthread_cond_t *Cond, const char *Name) {
	int Result;
	Result = pthread_cond_destroy(Cond);
	if (Result) {
		fprintf(stderr, _("pthread_cond_destroy (%s): %s\n"), Name, strerror(Result));
	}
}

void Safe_pthread_mutex_lock(pthread_mutex_t *Mutex) {
	int Return;
	if ((Return = pthread_mutex_lock(Mutex))) {
		fprintf(stderr, _("Acquiration of mutex %p failed with code %d: %s\n"), Mutex, Return, strerror(Return));
		exit(EXIT_FAILURE);
	}
}

void Safe_pthread_mutex_unlock(pthread_mutex_t *Mutex) {
	int Return;
	if ((Return = pthread_mutex_unlock(Mutex))) {
		fprintf(stderr, _("Releasing mutex %p failed with code %d: %s\n"), Mutex, Return, strerror(Return));
		exit(EXIT_FAILURE);
	}
}

